
# pyPreservica


[![Downloads](https://pepy.tech/badge/pyPreservica/month)](https://pepy.tech/project/pyPreservica/month)
[![Supported Versions](https://img.shields.io/pypi/pyversions/pyPreservica.svg)](https://pypi.org/project/pyPreservica)
[![CodeQL](https://github.com/carj/pyPreservica/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/carj/pyPreservica/actions/workflows/codeql-analysis.yml)

Python language binding for the Preservica API

https://preservica.com/

This library provides a Python class for working with the Preservica Rest API

https://developers.preservica.com/api-reference

Wiki with example scripts https://github.com/carj/pyPreservica/wiki

## Documentation

The full documentation is available at: https://pypreservica.readthedocs.io/

[![Documentation Status](https://readthedocs.org/projects/pypreservica/badge/?version=latest)](https://pypreservica.readthedocs.io/en/latest/?badge=latest)

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/carj/pyPreservica

For announcements about new versions and discussion of pyPreservica please subscribe to the google groups
forum https://groups.google.com/g/pypreservica

## License

The package is available as open source under the terms of the Apache License 2.0
